==> seismic_rna-0.9.5-py3-none-any.whl: seismicrna/core/arg/cmd.py <==
"""

Command Core Module

========================================================================

Define the names of the commands.

------------------------------------------------------------------------

"""


CMD_WHOLE = "all"
CMD_DEMULT = "demult"
CMD_QC = "qc"
CMD_ALIGN = "align"
CMD_REL = "relate"
CMD_MASK = "mask"
CMD_CLUST = "cluster"
CMD_TABLE = "table"
CMD_FOLD = "fold"
CMD_GRAPH = "graph"
CMD_EXPORT = "export"
CMD_SIM = "sim"
CMD_TEST = "test"
CMD_FASTACLEAN = "fastaclean"

########################################################################
#                                                                      #
# Copyright ©2023, the Rouskin Lab.                                    #
#                                                                      #
# This file is part of SEISMIC-RNA.                                    #
#                                                                      #
# SEISMIC-RNA is free software; you can redistribute it and/or modify  #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation; either version 3 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# SEISMIC-RNA is distributed in the hope that it will be useful, but   #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT- #
# ABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General     #
# Public License for more details.                                     #
#                                                                      #
# You should have received a copy of the GNU General Public License    #
# along with SEISMIC-RNA; if not, see <https://www.gnu.org/licenses>.  #
#                                                                      #
########################################################################

==> seismic_rna-0.11.2-py3-none-any.whl: seismicrna/core/arg/cmd.py <==
"""

Command Core Module

========================================================================

Define the names of the commands.

------------------------------------------------------------------------

"""


CMD_WORKFLOW = "wf"
CMD_DEMULT = "demult"
CMD_QC = "qc"
CMD_ALIGN = "align"
CMD_REL = "relate"
CMD_POOL = "pool"
CMD_MASK = "mask"
CMD_CLUST = "cluster"
CMD_TABLE = "table"
CMD_FOLD = "fold"
CMD_GRAPH = "graph"
CMD_EXPORT = "export"
CMD_CLEANFA = "+cleanfa"
CMD_RENUMCT = "+renumct"
CMD_SIM = "+sim"
CMD_TEST = "+test"

########################################################################
#                                                                      #
# © Copyright 2024, the Rouskin Lab.                                   #
#                                                                      #
# This file is part of SEISMIC-RNA.                                    #
#                                                                      #
# SEISMIC-RNA is free software; you can redistribute it and/or modify  #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation; either version 3 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# SEISMIC-RNA is distributed in the hope that it will be useful, but   #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT- #
# ABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General     #
# Public License for more details.                                     #
#                                                                      #
# You should have received a copy of the GNU General Public License    #
# along with SEISMIC-RNA; if not, see <https://www.gnu.org/licenses>.  #
#                                                                      #
########################################################################
